fn process_backup_dir_entry(entry: DirEntry) -> Option<(Hash, PathBuf)>Expand description
Accepts a DirEntry from the non-finalized state backup directory and
parses the filename into a block hash.
Returns the block hash and the file path if successful, or returns None and deletes the file at the entry path otherwise.