fn write_backup_block(backup_dir_path: &Path, block: &ContextuallyVerifiedBlock)Expand description
Writes a block to a file in the provided non-finalized state backup cache directory path.
fn write_backup_block(backup_dir_path: &Path, block: &ContextuallyVerifiedBlock)Writes a block to a file in the provided non-finalized state backup cache directory path.